# Magani

## API Testing Tool

* Developed in pure Python
* REST API testing software


Create test cases and test in project level as well as test case level. Only Public API is supporting. You can use inside private network without authentication.


### Testing methods

* GET : Implemented
* POST : Implemented
* PUT : Implemented
* DELETE : Implemented

### Authorization 

* Basic Auth : Not Implemented


### Reports

* Export Project wise CSV file
* Export Project wise Excel file

### Future Support

* Export All test case results in pdf, docs.
* Basic auth support

## Setup

To use the software python is required.

Open the terminal & follow the instructions 

Type to install Magani 

    $ pip install magani

Type to run the Magani software

    $ magani

**Note**:

* It will support for Windows & Linux

## Developer Setup

Clone it

    $ git clone https://github.com/Magani-Stack/magani.git

Run

    $ python magani_app.py

### Contribution
We welcome contributor in the category as follows
* Contribute Code Changes
* Contributing by Reviewing Changes
* Contributing Documentation Changes
* Contributing Bug Reports
* Contributing by Testing Releases


### Code Style Guide
Please follow the style of the existing codebase.

For Python code, Magani follows PEP 8 with one exception: lines can be up to 120 characters in length, not 79.


### [Learn More](https://github.com/Magani-Stack/docs/blob/master/Tour/Create_Project.md)

